.. -*- mode: rst -*-

.. include:: changes/names.rst

====
Team
====

This work is made available by a community of people, which
originated from
the :BoA:`Biomarkers of Aging Consortium <>`

.. _core_devs:

Core developers
...............

The biolearn core developers are:

* `Mahdi Moqri`_  /  `Researcher & BoA Executive <https://www.linkedin.com/in/mahdi-moqri-41432547/>`_
* `Martin Perez-Guevara`_  /  `Machine Learning Engineer <https://www.linkedin.com/in/martin-perez-guevara/>`_
* `Seth Paulson`_  /  `Software Architect <https://www.linkedin.com/in/seth-paulson-6ba80226/>`_

Other contributors
..................

* `Albert Ying`_ / `Harvard Universiy <https://scholar.google.com/citations?user=JS7AdkcAAAAJ&hl=zh-CN>`_
* `Dayoon Kwon`_ /  `University of California <https://scholar.google.com/citations?user=5L9djqsAAAAJ&hl=en>`_


Special thanks to scientific and executive members of the :BoA:`Biomarkers of Aging Consortium <>`
